ExtendedNextHopCapability

Struct ExtendedNextHopCapability 

pub struct ExtendedNextHopCapability {
    pub entries: Vec<ExtendedNextHopEntry>,
}
Extended Next Hop capability - RFC 8950, Section 3 Contains a list of supported NLRI/NextHop AFI/SAFI combinations

Fields

entries: Vec<ExtendedNextHopEntry>

List of supported AFI/SAFI combinations for extended next hop encoding

Implementations

Source

impl ExtendedNextHopCapability

pub fn new(entries: Vec<ExtendedNextHopEntry>) -> Self

Create a new Extended Next Hop capability with the given entries

pub fn supports(&self, nlri_afi: Afi, nlri_safi: Safi, nexthop_afi: Afi) -> bool

Check if this capability supports a specific NLRI AFI/SAFI with NextHop AFI combination

pub fn supported_nlri_for_nexthop(&self, nexthop_afi: Afi) -> Vec<(Afi, Safi)>

Get all supported NLRI AFI/SAFI combinations for a given NextHop AFI

pub fn parse(data: Bytes) -> Result<Self, ParserError>

Parse Extended Next Hop capability from raw bytes - RFC 8950, Section 3

Format: Series of 6-byte entries, each containing:

  • NLRI AFI (2 bytes)
  • NLRI SAFI (2 bytes)
  • NextHop AFI (2 bytes)
pub fn encode(&self) -> Bytes

Encode Extended Next Hop capability to raw bytes - RFC 8950, Section 3