LabeledNlriMode

Enum LabeledNlriMode 

pub enum LabeledNlriMode {
    SingleLabel,
    MultiLabel,
}
RFC 8277 parsing mode for labeled NLRI

RFC 8277 defines two distinct encoding modes that are NOT compatible on the wire:

  • SingleLabel (2.2): No Multiple Labels Capability negotiated. Exactly one label, S-bit MUST be ignored on reception.

  • MultiLabel (2.3): Multiple Labels Capability negotiated. Multiple labels allowed, use BoS bit to delimit stack.

Variants



SingleLabel

RFC 8277 2.2: Single-label encoding (no Multiple Labels Capability negotiated). In this mode, exactly one label is expected and the S-bit is ignored. Note: Using this mode with multi-label data will result in parse errors.



MultiLabel

RFC 8277 2.3: Multi-label encoding (Multiple Labels Capability negotiated). This is the default as it correctly handles both single-label and multi-label prefixes.