#[repr(u16)]pub enum PeerUpTlvType {
String = 0,
SysDescr = 1,
SysName = 2,
VrTableName = 3,
AdminLabel = 4,
Unknown(u16),
}Expand description
BMP Peer Up Message TLV Type
https://www.iana.org/assignments/bmp-parameters/bmp-parameters.xhtml#peer-up-message-tlvs
RFC 9736 created an independent namespace for Peer Up Information TLVs, separate from the Initiation message namespace. Per the new registry, types 1, 2, and 65535 are reserved. The SysDescr and SysName variants are retained for backward compatibility with pre-RFC 9736 implementations.
Variants
String = 0
SysDescr = 1
Reserved per RFC 9736, retained for backward compatibility.
SysName = 2
Reserved per RFC 9736, retained for backward compatibility.
VrTableName = 3
AdminLabel = 4
Unknown(u16)