pub struct RecoveryConfig { /* private fields */ }Expand description
Settings for opt-in MRT framing recovery.
Implementations
Sourceimpl RecoveryConfig
impl RecoveryConfig
Sourcepub const fn with_max_scan_bytes(self, max_scan_bytes: usize) -> Self
pub const fn with_max_scan_bytes(self, max_scan_bytes: usize) -> Self
Set the maximum number of bytes searched after a damaged record.
Sourcepub const fn with_confirmation_records(self, confirmation_records: u8) -> Self
pub const fn with_confirmation_records(self, confirmation_records: u8) -> Self
Set the number of consecutive records required to confirm a recovered boundary.
A value of zero is treated as one.
pub const fn max_scan_bytes(&self) -> usize
pub const fn confirmation_records(&self) -> u8