Module mrt_elem

Module mrt_elem 

This module handles converting MRT records into individual per-prefix BGP elements.

Each MRT record may contain reachability information for multiple prefixes. This module breaks down MRT records into corresponding BGP elements, and thus allowing users to more conveniently process BGP information on a per-prefix basis.

Structs

BgpUpdateElemIter
Iterator over BgpElems produced from a BgpUpdateMessage, avoiding allocation by lazily yielding elements from announced and withdrawn prefixes in two phases.
Elementor

Enums

ElemError
Error returned by Elementor::record_to_elems_iter.
RecordElemIter
Iterator over BgpElems produced from a single MrtRecord, without requiring a mutable reference to the Elementor.

Functions

option_to_string