Struct bgpkit_parser::parser::BgpkitParser
source · pub struct BgpkitParser<R> { /* private fields */ }Implementations
sourceimpl<R> BgpkitParser<R>
impl<R> BgpkitParser<R>
pub fn into_record_iter(self) -> RecordIterator<R> ⓘ
pub fn into_elem_iter(self) -> ElemIterator<R> ⓘ
sourceimpl<R: Read> BgpkitParser<R>
impl<R: Read> BgpkitParser<R>
sourcepub fn from_reader(reader: R) -> Self
pub fn from_reader(reader: R) -> Self
Creating a new parser from a object that implements Read trait.
sourcepub fn next_record(&mut self) -> Result<MrtRecord, ParserErrorWithBytes>
pub fn next_record(&mut self) -> Result<MrtRecord, ParserErrorWithBytes>
This is used in for loop for item in parser{}