Struct bgpkit_parser::PeerIndexTable
source · [−]pub struct PeerIndexTable {
pub collector_bgp_id: Ipv4Addr,
pub view_name_length: u16,
pub view_name: String,
pub peer_count: u16,
pub peers_map: HashMap<u32, Peer, RandomState>,
}Expand description
peer index table.
An initial PEER_INDEX_TABLE MRT record provides the BGP ID of the
collector, an OPTIONAL view name, and a list of indexed peers.
Following the PEER_INDEX_TABLE MRT record, a series of MRT records is
used to encode RIB table entries. This series of MRT records uses
subtypes 2-6 and is separate from the PEER_INDEX_TABLE MRT record
itself and includes full MRT record headers. The RIB entry MRT
records MUST immediately follow the PEER_INDEX_TABLE MRT record.Fields
collector_bgp_id: Ipv4Addrview_name_length: u16view_name: Stringpeer_count: u16peers_map: HashMap<u32, Peer, RandomState>Trait Implementations
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.
pub fn serialize<__S>(
&self,
__serializer: __S
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error> where
__S: Serializer,
pub fn serialize<__S>(
&self,
__serializer: __S
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error> where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more