Struct bgpkit_parser::RibGenericEntries
source · [−]pub struct RibGenericEntries {
pub sequence_number: u32,
pub afi: Afi,
pub safi: Safi,
pub nlri: NetworkPrefix,
pub rib_entries: Vec<RibEntry, Global>,
}Expand description
RIB generic entries subtype.
The RIB_GENERIC header is shown below. It is used to cover RIB
entries that do not fall under the common case entries defined above.
It consists of an AFI, Subsequent AFI (SAFI), and a single NLRI
entry. The NLRI information is specific to the AFI and SAFI values.
An implementation that does not recognize particular AFI and SAFI
values SHOULD discard the remainder of the MRT record.
0 1 2 3
0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 0 1
+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
| Sequence Number |
+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
| Address Family Identifier |Subsequent AFI |
+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
| Network Layer Reachability Information (variable) |
+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
| Entry Count | RIB Entries (variable)
+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+Fields
sequence_number: u32afi: Afisafi: Safinlri: NetworkPrefixrib_entries: Vec<RibEntry, Global>Trait Implementations
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.
pub fn serialize<__S>(
&self,
__serializer: __S
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error> where
__S: Serializer,
pub fn serialize<__S>(
&self,
__serializer: __S
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error> where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more