Attributes

Struct Attributes 

pub struct Attributes { /* private fields */ }
Convenience wrapper for a list of attributes

Implementations

Source

impl Attributes

pub fn has_attr(&self, ty: AttrType) -> bool

pub fn get_attr(&self, ty: AttrType) -> Option<Attribute>

pub fn add_attr(&mut self, attr: Attribute)

pub fn check_mandatory_attributes( &mut self, is_announcement: bool, has_standard_nlri: bool, )

Check for missing well-known mandatory attributes.

RFC 4271 (BGP-4) and RFC 4760 (MP-BGP) define which attributes are mandatory.

  • Pure Withdrawals: NO path attributes are required.
  • Announcements: ORIGIN and AS_PATH are strictly required.
  • NEXT_HOP is required if standard IPv4 NLRI is present or if no MP_REACH_NLRI is present.
pub fn add_validation_warning(&mut self, warning: BgpValidationWarning)

Add a validation warning to the attributes

pub fn validation_warnings(&self) -> &[BgpValidationWarning]

Get all validation warnings for these attributes

pub fn has_validation_warnings(&self) -> bool

Check if there are any validation warnings

pub fn origin(&self) -> Origin

Get the ORIGIN attribute. In the event that this attribute is not present, Origin::INCOMPLETE will be returned instead.

pub fn origin_id(&self) -> Option<BgpIdentifier>

Get the ORIGINATOR_ID attribute if present.

pub fn next_hop(&self) -> Option<IpAddr>

Get the NEXT_HOP attribute if present.

Note: Even when this attribute is not present, the next hop address may still be attainable from the MP_REACH_NLRI attribute.

pub fn multi_exit_discriminator(&self) -> Option<u32>

pub fn local_preference(&self) -> Option<u32>

pub fn only_to_customer(&self) -> Option<Asn>

pub fn atomic_aggregate(&self) -> bool

pub fn aggregator(&self) -> Option<(Asn, BgpIdentifier)>

pub fn clusters(&self) -> Option<&[u32]>

pub fn as_path(&self) -> Option<&AsPath>

pub fn get_reachable_nlri(&self) -> Option<&Nlri>

pub fn get_unreachable_nlri(&self) -> Option<&Nlri>

pub fn iter_communities(&self) -> MetaCommunitiesIter<'_>

pub fn iter(&self) -> <&Self as IntoIterator>::IntoIter

Get an iterator over the held AttributeValues. If you also need attribute flags, consider using Attributes::into_attributes_iter instead.

pub fn into_attributes_iter(self) -> impl Iterator<Item = Attribute>

Get an iterator over the held Attributes. If you do no not need attribute flags, consider using Attributes::iter instead.

Source

impl Attributes

pub fn encode(&self, asn_len: AsnLength) -> Bytes