Iterator implementations for bgpkit-parser.
This module contains different iterator implementations for parsing BGP data:
default: Standard iterators that skip errors (RecordIterator, ElemIterator)fallible: Fallible iterators that return Results (FallibleRecordIterator, FallibleElemIterator)update: Iterators for BGP UPDATE messages (UpdateIterator, FallibleUpdateIterator)
It also contains the trait implementations that enable BgpkitParser to be used with Rust’s iterator syntax.
Re-exports
pub use default::ElemIterator;pub use default::RecordIterator;pub use fallible::FallibleElemIterator;pub use fallible::FallibleRecordIterator;
Modules
- default
- Default iterator implementations that skip errors and return successfully parsed items.
- fallible
- Fallible iterator implementations that return Results, exposing parsing errors to users.
Structs
- Bgp4
MpUpdate - A BGP4MP UPDATE message with associated metadata.
- Diagnostic
Iterator - Iterator over record-level parsing diagnostics.
- Fallible
Route Iterator - Fallible
Update Iterator - Fallible iterator over BGP announcements that returns parsing errors.
- Legacy
BgpUpdate - A deprecated MRT Type 5 BGP_UPDATE message with endpoint metadata.
- RawRecord
Iterator - Recovering
Elem Iterator - Iterator over BGP elements and explicit recovery gaps.
- Recovering
Record Iterator - Iterator over parsed MRT records and explicit recovery gaps.
- Recovery
Config - Settings for opt-in MRT framing recovery.
- Recovery
Error - A framing error for which no recovery boundary was found within the scan window, an I/O failure, or unsupported input.
- Recovery
Gap - A byte range discarded while restoring MRT record framing.
- Route
Iterator - Table
Dump V2Entry - A TableDumpV2 RIB entry with associated metadata.
- Update
Iterator - Iterator over BGP announcements from MRT data.
Enums
- Diagnostic
Event - A record-level parsing outcome for malformed-data investigation.
- MrtUpdate
- Unified enum representing BGP announcements from different MRT message types.
- Recovery
Event - An item produced by a recovering iterator.
- Recovery
Evidence - Evidence used to validate the first record following a recovered gap.