Struct bgpkit_parser::parser::BgpkitParser
source · pub struct BgpkitParser { /* private fields */ }Implementations
sourceimpl BgpkitParser
impl BgpkitParser
pub fn into_record_iter(self) -> RecordIterator ⓘ
pub fn into_elem_iter(self) -> ElemIterator ⓘ
sourceimpl BgpkitParser
impl BgpkitParser
sourcepub fn new(path: &str) -> Result<BgpkitParser, ParserErrorWithBytes>
pub fn new(path: &str) -> Result<BgpkitParser, ParserErrorWithBytes>
Creating a new parser from a object that implements [Read] trait.
pub fn enable_core_dump(self) -> BgpkitParser
pub fn disable_warnings(self) -> BgpkitParser
pub fn add_filter(
self,
filter_type: &str,
filter_value: &str
) -> Result<BgpkitParser, ParserErrorWithBytes>
sourcepub fn next_record(&mut self) -> Result<MrtRecord, ParserErrorWithBytes>
pub fn next_record(&mut self) -> Result<MrtRecord, ParserErrorWithBytes>
This is used in for loop for item in parser{}